summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/gwprotocol.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/groupwise/gwprotocol.cpp')
-rw-r--r--kopete/protocols/groupwise/gwprotocol.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/protocols/groupwise/gwprotocol.cpp b/kopete/protocols/groupwise/gwprotocol.cpp
index 68a31fb4..237122c6 100644
--- a/kopete/protocols/groupwise/gwprotocol.cpp
+++ b/kopete/protocols/groupwise/gwprotocol.cpp
@@ -5,7 +5,7 @@
Based on Testbed
Copyright (c) 2003 by Will Stephenson <will@stevello.free-online.co.uk>
- rtfizeTest from nm_rtfize_text, from Gaim src/protocols/novell/nmuser.c
+ rtfizeTest from nm_rtfize_text, from Pidgin src/protocols/novell/nmuser.c
Copyright (c) 2004 Novell, Inc. All Rights Reserved
Kopete (c) 2002-2003 by the Kopete developers <kopete-devel@kde.org>
@@ -178,7 +178,7 @@ TQString GroupWiseProtocol::rtfizeText( const TQString & plain )
"{\\colortbl ;\\red0\\green0\\blue0;}\n"
"\\uc1\\cf1\\f0\\fs18 %1\\par\n}");
TQString outputText; // output text
- TQCString plainUtf8 = plain.utf8(); // encoded as UTF8, because that's what this encoding algorithm, taken from Gaim's Novell plugin
+ TQCString plainUtf8 = plain.utf8(); // encoded as UTF8, because that's what this encoding algorithm, taken from Pidgin's Novell plugin
uint index = 0; // current char to transcode
while ( index < plainUtf8.length() )
{